@@ -10,10 +10,10 @@ import threading
 
 
 class DownloadClient:
-    def __init__(self, ip, port):
+    def __init__(self, ip, port, group_name):
         self.ip = ip
         self.port = port
-        self.data_path = os.path.dirname(os.path.abspath(__file__)) + '/data/cache'
+        self.data_path = os.path.dirname(os.path.abspath(__file__)) + '/data/cache/' + group_name
         print(self.data_path)
         self.compressed_path = self.data_path + '/to_send.zip'
         print(self.data_path)
@@ -86,7 +86,7 @@ class DownloadClient:
                             received_size += 4
                         received_size += len(data)
                     else:
-                        data = conn.recv(file_size-received_size)
+                        data = conn.recv(file_size - received_size)
                         if strip_flag:
                             data = data.lstrip(b'\00\00\00\00')
                             strip_flag = False
@@ -109,4 +109,3 @@ if __name__ == "__main__":
     t.setDaemon(True)
     t.start()
     sleep(20)
-
