@@ -8,7 +8,7 @@ import re
 
 class SearchEngine:
     def __init__(self, download_server_ip, download_server_port, download_client_ip, download_client_port,
-                 es_ip, es_port, index_name, video_index_name):
+                 es_ip, es_port, index_name, video_index_name, group_name):
         """
         1.调用DowonloadClient中的file_tag()检查文件是否下好，
         如果没下好，先调用DownloadClient中的download()进行下载
@@ -20,7 +20,7 @@ class SearchEngine:
         :param es_ip: es服务的ip
         :param es_port: es服务的端口
         """
-        self.client = DownloadClient(download_client_ip, download_client_port)
+        self.client = DownloadClient(download_client_ip, download_client_port, group_name)
         self.es = ESClient([{"host": es_ip, "port": es_port}], index_name=index_name, video_index_name=video_index_name)
         self.titles = []
         self.send_flag = [False]
@@ -84,9 +84,10 @@ class SearchEngine:
         try:
             res = self.es.search_by_id(id_)
         except BaseException as e:
+            print(e)
             print("id doesn't exist")
             return {}
         abs_dirname = os.path.dirname(os.path.abspath(__file__))
         res["pdfPath"] = abs_dirname + res["pdfPath"]
         res["videoPath"] = abs_dirname + res["videoPath"]
-        return res
\ No newline at end of file
+        return res
